%global         pypi_name      cobaya

Name:           python-cobaya
Version:        3.3.1
Release:        %mkrel 4
Summary:        A python sampler for Bayesian analysis
License:        LGPLv3
Group:          Development/Python
URL:            https://pypi.python.org/pypi/cobaya
Source0:        %{pypi_source}

BuildArch:      noarch


#use thefuzz instead of deprecated fuzzywuzzy package
Patch0:         cobaya-3.3.1-thefuzz.patch
#remove fallback to potentially inexistent initpowerlaw class
Patch1:         cobaya-3.3.1-cambinitpower.patch
#missing method in class
Patch2:         cobaya-3.3.1-trieswarning.patch

%description
Cobaya (code for bayesian analysis, and Spanish for Guinea Pig) is a
framework for sampling and statistical modelling: it allows you to
explore an arbitrary prior or posterior using a range of Monte Carlo
samplers (including some advanced MCMC and nested samplers). The
results of the sampling can be analysed with GetDist. It supports MPI
parallelization.


%package -n python3-cobaya
Summary:        A python sampler for Bayesian analysis
Group:          Development/Python
%{?python_provide:%python_provide python3-cobaya}
BuildRequires:  python3
BuildRequires:  python3dist(setuptools)
BuildRequires:  pyproject-rpm-macros
Requires:       python3dist(numpy)
Requires:       python3dist(scipy)
Requires:       python3dist(pandas)
Requires:       python3dist(pyyaml)
Requires:       python3dist(requests)
Requires:       python3dist(py-bobyqa)
Requires:       python3dist(getdist)
Requires:       python3dist(thefuzz)
Requires:       python3dist(packaging)
Requires:       python3dist(tqdm)
Requires:       python3dist(portalocker)
Requires:       python3dist(dill)
Requires:       python3dist(pytest)
Requires:       python3dist(flaky)
Requires:       python3dist(mpi4py)
Requires:       python3dist(pyside6)
Requires:       python3dist(matplotlib)
Requires:       python3dist(urllib3)
Requires:       python3dist(idna)
Requires:       python3dist(charset-normalizer)
Requires:       python3dist(pytz)
Requires:       python3dist(python-dateutil)
Requires:       python3dist(kiwisolver)
Requires:       python3dist(pyparsing)
Requires:       python3dist(fonttools)
Requires:       python3dist(cycler)
Requires:       python3dist(contourpy)
Requires:       python3dist(six)

Provides:       cobaya = %{version}-%{release}

%description -n python3-cobaya
Cobaya (code for bayesian analysis, and Spanish for Guinea Pig) is a
framework for sampling and statistical modelling: it allows you to
explore an arbitrary prior or posterior using a range of Monte Carlo
samplers (including some advanced MCMC and nested samplers). The
results of the sampling can be analysed with GetDist. It supports MPI
parallelization.


%prep
%setup -q -n %{pypi_name}-%{version}
%autopatch -p1

# Remove bundled egg-info
%__rm -rf %{pypi_name}.egg-info

%build
%pyproject_wheel

%install
%py3_install

%files -n python3-cobaya
%doc README.rst
%{_bindir}/cobaya*
%{python3_sitelib}/cobaya
%{python3_sitelib}/%{pypi_name}-%{version}-py%{python3_version}.egg-info


%changelog
* Fri Jun 09 2023 eatdirt <eatdirt> 3.3.1-4.mga9
+ Revision: 1961453
- Fix missing attribute in mcmc object

* Fri Jun 02 2023 eatdirt <eatdirt> 3.3.1-3.mga9
+ Revision: 1960558
- Fix bug in camb module

* Tue May 30 2023 eatdirt <eatdirt> 3.3.1-2.mga9
+ Revision: 1959853
- Fix python3dist requires names

* Tue May 30 2023 eatdirt <eatdirt> 3.3.1-1.mga9
+ Revision: 1959819
- imported package python-cobaya

